@@ -99,9 +99,10 @@ gvisWelcomeMessage <- function(){
         "Note, the plot method of googleVis will by default use\n",
         display,
         "\n",
-        "See the googleVis package vignettes for more details.\n",
+        "See the googleVis package vignettes for more details,\n",
+        "or visit http://github.com/mages/googleVis.\n",
         "\n",               
-        "To suppress the this message use:\n",
+        "To suppress this message use:\n",
         "suppressPackageStartupMessages(library(googleVis))\n",  
           sep="")
 }
